package cc.fascinated.bat.common.feature;

import cc.fascinated.bat.common.oldcommand.BatCommand;
import cc.fascinated.bat.service.OldCommandService;
import lombok.Getter;
import lombok.NonNull;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Component;

/**
 * @author Fascinated (fascinated7)
 */
@RequiredArgsConstructor
@Getter
@Component
public abstract class Feature {
    /**
     * The name of the feature
     */
    private final String name;

    /**
     * The default state of the feature
     */
    private final FeatureProfile.FeatureState defaultState;

    /**
     * The description of the feature
     */
    public final boolean canBeDisabled;

    /**
     * Registers the command for the feature
     *
     * @param commandService The command service
     * @param command        The command to register
     */
    public void registerCommand(@NonNull OldCommandService commandService, @NonNull BatCommand command) {
        command.setFeature(this);
        for (BatCommand subCommand : command.getSubCommands().values()) {
            subCommand.setFeature(this);
        }
        commandService.registerCommand(command);
    }
}
